@@ -7,7 +7,7 @@ use Moo;
 use MooX::StrictConstructor;
 use namespace::autoclean;
 
-our $VERSION = '1.005';
+our $VERSION = '1.006';
 
 with qw(
     Locale::TextDomain::OO::Lexicon::Role::File
@@ -30,13 +30,13 @@ __END__
 
 Locale::TextDomain::OO::Lexicon::File::MO - Gettext mo file as lexicon
 
-$Id: MO.pm 457 2014-01-06 13:27:38Z steffenw $
+$Id: MO.pm 461 2014-01-09 07:57:37Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk/lib/Locale/TextDomain/OO/Lexicon/File/MO.pm $
 
 =head1 VERSION
 
-1.005
+1.006
 
 =head1 DESCRIPTION
 
@@ -58,7 +58,7 @@ This module reads a gettext mo file into the lexicon.
             # optional
             logger => sub {
                 my ($message, $arg_ref) = @_;
-                my $type = $arg_ref->{type}; # info, warn or error
+                my $type = $arg_ref->{type}; # debug
                 Log::Log4perl->get_logger(...)->$type($message);
                 return;
             },
@@ -112,7 +112,7 @@ Set the logger
 $arg_ref contains
 
     object => $lexicon_file_mo, # the object itself
-    type   => 'info',
+    type   => 'debug',
     event  => 'lexicon,load',
 
 =head1 EXAMPLE
